// Copyright (C) 2016 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.gerrit.server.notedb.rebuild;

import com.google.gerrit.reviewdb.client.Account;
import com.google.gerrit.reviewdb.client.PatchSet;
import com.google.gerrit.server.notedb.ChangeUpdate;
import com.google.gwtorm.server.OrmException;

import java.sql.Timestamp;
import java.util.Set;

class HashtagsEvent extends Event {
  private final Set<String> hashtags;

  HashtagsEvent(PatchSet.Id psId, Account.Id who, Timestamp when,
      Set<String> hashtags, Timestamp changeCreatdOn) {
    super(psId, who, who, when, changeCreatdOn,
        // Somewhat confusingly, hashtags do not use the setTag method on
        // AbstractChangeUpdate, so pass null as the tag.
        null);
    this.hashtags = hashtags;
  }

  @Override
  boolean uniquePerUpdate() {
    // Since these are produced from existing commits in the old NoteDb graph,
    // we know that there must be one per commit in the rebuilt graph.
    return true;
  }

  @Override
  void apply(ChangeUpdate update) throws OrmException {
    update.setHashtags(hashtags);
  }
}
